@@ -1,4 +1,4 @@
-from ubersmith.api import HttpRequestHandler, set_default_request_handler
+from ubersmith.api import RequestHandler, set_default_request_handler
 
 __all__ = [
     # package modules
@@ -19,8 +19,8 @@ __all__ = [
 ]
 
 
-def init(base_url, username=None, password=None):
+def init(base_url, username=None, password=None, verify=True):
     """Initialize ubersmith API module with HTTP request handler."""
-    handler = HttpRequestHandler(base_url, username, password)
+    handler = RequestHandler(base_url, username, password, verify)
     set_default_request_handler(handler)
     return handler
